// main.js

// Modules to control application life and create native browser window
const { app, BrowserWindow, shell } = require("electron");
const windowStateKeeper = require("electron-window-state");
const path = require("path");

function createWindow() {
  let mainWindowState = windowStateKeeper({
    defaultWidth: 400,
    defaultHeight: 700,
  });

  // Create the browser window.
  const mainWindow = new BrowserWindow({
    width: mainWindowState.width || 400,
    height: mainWindowState.height || 700,
    x: mainWindowState.x,
    y: mainWindowState.y,
    titleBarStyle: "hidden",
    // titleBarOverlay: {
    //   color: "red",
    //   symbolColor: "gray",
    // },
    //webPreferences: {
    //  preload: path.join(__dirname, 'preload.js')
    //}
  });

  mainWindowState.manage(mainWindow);

  // and load the index.html of the app.
  app.dock.hide();
  mainWindow.loadURL("https:pomofocus.io/app");
  // mainWindow.loadURL("http://localhost:8080/app");
  mainWindow.setAlwaysOnTop(true, "floating");
  mainWindow.setVisibleOnAllWorkspaces(true);
  mainWindow.setFullScreenable(false);
  mainWindow.setMenu(null);

  mainWindow.webContents.on("new-window", function (e, url) {
    e.preventDefault();
    shell.openExternal(url);
  });

  // Open the DevTools.
  // mainWindow.webContents.openDevTools()
}

// This method will be called when Electron has finished
// initialization and is ready to create browser windows.
// Some APIs can only be used after this event occurs.
app.whenReady().then(() => {
  createWindow();

  app.on("activate", function () {
    // On macOS it's common to re-create a window in the app when the
    // dock icon is clicked and there are no other windows open.
    if (BrowserWindow.getAllWindows().length === 0) createWindow();
  });
});

// Quit when all windows are closed, except on macOS. There, it's common
// for applications and their menu bar to stay active until the user quits
// explicitly with Cmd + Q.
app.on("window-all-closed", function () {
  if (process.platform !== "darwin") app.quit();
});

// In this file you can include the rest of your app's specific main process
// code. You can also put them in separate files and require them here.
